summaryrefslogtreecommitdiff
path: root/tools/node_modules/eslint/node_modules/rxjs/src/internal/operators/shareReplay.ts
diff options
context:
space:
mode:
Diffstat (limited to 'tools/node_modules/eslint/node_modules/rxjs/src/internal/operators/shareReplay.ts')
-rw-r--r--tools/node_modules/eslint/node_modules/rxjs/src/internal/operators/shareReplay.ts4
1 files changed, 2 insertions, 2 deletions
diff --git a/tools/node_modules/eslint/node_modules/rxjs/src/internal/operators/shareReplay.ts b/tools/node_modules/eslint/node_modules/rxjs/src/internal/operators/shareReplay.ts
index aa8505049c..3d5371fea9 100644
--- a/tools/node_modules/eslint/node_modules/rxjs/src/internal/operators/shareReplay.ts
+++ b/tools/node_modules/eslint/node_modules/rxjs/src/internal/operators/shareReplay.ts
@@ -38,7 +38,7 @@ import { Subscriber } from '../Subscriber';
* @see {@link publishReplay}
*
* @param {Number} [bufferSize=Number.POSITIVE_INFINITY] Maximum element count of the replay buffer.
* @param {Number} [windowTime=Number.MAX_VALUE] Maximum time length of the replay buffer in milliseconds.
* @param {Scheduler} [scheduler] Scheduler where connected observers within the selector function
* will be invoked on.
* @return {Observable} An observable sequence that contains the elements of a sequence produced
@@ -48,7 +48,7 @@ import { Subscriber } from '../Subscriber';
*/
export function shareReplay<T>(
bufferSize: number = Number.POSITIVE_INFINITY,
- windowTime: number = Number.MAX_VALUE,
+ windowTime: number = Number.POSITIVE_INFINITY,
scheduler?: SchedulerLike
): MonoTypeOperatorFunction<T> {
return (source: Observable<T>) => source.lift(shareReplayOperator(bufferSize, windowTime, scheduler));
@@ -38,7 +38,7 @@ import { Subscriber } from '../Subscriber';
*
* @param {Number} [bufferSize=Number.POSITIVE_INFINITY] Maximum element count of the replay buffer.
- * @param {Number} [windowTime=Number.MAX_VALUE] Maximum time length of the replay buffer in milliseconds.
+ * @param {Number} [windowTime=Number.POSITIVE_INFINITY] Maximum time length of the replay buffer in milliseconds.
* @param {Scheduler} [scheduler] Scheduler where connected observers within the selector function
* will be invoked on.